@@ -16,23 +16,27 @@
 import re
 import yaml
 
-from .. import LintProblem
-from ..generators import CfyNode
-from ..utils import process_relevant_tokens, INTRINSIC_FNS, context as ctx
-from .constants import (GCP_TYPES,
-                        AWS_TYPES,
-                        AZURE_TYPES,
-                        TERRAFORM_TYPES,
-                        AWS_VALID_KEY,
-                        AZURE_VALID_KEY,
-                        TFLINT_SUPPORTED_CONFIGS,
-                        TERRATAG_SUPPORTED_FLAGS,
-                        deprecated_node_types,
-                        REQUIRED_RELATIONSHIPS,
-                        firewall_rule_gcp,
-                        security_group_validation_aws,
-                        security_group_validation_azure,
-                        security_group_validation_openstack)
+from cfy_lint.yamllint_ext import LintProblem
+from cfy_lint.yamllint_ext.generators import CfyNode
+from cfy_lint.yamllint_ext.utils import (process_relevant_tokens,
+                                         INTRINSIC_FNS,
+                                         context as ctx)
+from cfy_lint.yamllint_ext.rules.constants import (
+    GCP_TYPES,
+    AWS_TYPES,
+    AZURE_TYPES,
+    TERRAFORM_TYPES,
+    AWS_VALID_KEY,
+    AZURE_VALID_KEY,
+    TFLINT_SUPPORTED_CONFIGS,
+    TERRATAG_SUPPORTED_FLAGS,
+    deprecated_node_types,
+    REQUIRED_RELATIONSHIPS,
+    firewall_rule_gcp,
+    security_group_validation_aws,
+    security_group_validation_azure,
+    security_group_validation_openstack,
+)
 
 VALUES = []
 
@@ -137,7 +141,8 @@ def validate_instrinsic_function(key, value, line):
             )
     elif key in ['get_attribute', 'get_property']:
         if value[0] not in ctx.get('node_templates', {}) and \
-                value[0] not in ctx.get('imported_node_templates', {}):
+                value[0] not in ctx.get('imported_node_templates', {}) \
+                and value[0] not in ['SELF', 'TARGET', 'SOURCE']:
             yield LintProblem(
                 line,
                 None,
@@ -224,7 +229,7 @@ def check_azure_config(model, line):
                 model.name))
     client_config = model.properties.get('client_config', {})
     if not all(x in AZURE_VALID_KEY for x in client_config.keys()):
-        if 'get_input' not in model.properties['client_config'] or \
+        if 'get_input' not in model.properties['client_config'] and \
                 'get_secret' not in model.properties['client_config']:
             yield LintProblem(line,
                               None,
@@ -243,7 +248,7 @@ def check_aws_config(model, line):
                 model.name))
     client_config = model.properties.get('client_config')
     if not all(x in AWS_VALID_KEY for x in client_config.keys()):
-        if 'get_input' not in model.properties['client_config'] or \
+        if 'get_input' not in model.properties['client_config'] and \
                 'get_secret' not in model.properties['client_config']:
             yield LintProblem(line,
                               None,
